==> pf4-component-mapper-3.16.0.tgz: package/esm/text-field/text-field.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["label", "isRequired", "helperText", "meta", "validateOnMount", "description", "hideLabel", "input", "isReadOnly", "isDisabled", "id", "FormGroupProps"];
import React from 'react';
import FormGroup from '../form-group/form-group';
import { TextInput } from "@patternfly/react-core/dist/esm/components/TextInput/TextInput.js";
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import showError from '../show-error/show-error';

var TextField = function TextField(props) {
  var _useFieldApi = useFieldApi(props),
      label = _useFieldApi.label,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      hideLabel = _useFieldApi.hideLabel,
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      id = _useFieldApi.id,
      FormGroupProps = _useFieldApi.FormGroupProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  return /*#__PURE__*/React.createElement(FormGroup, {
    label: label,
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: hideLabel,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(TextInput, _extends({}, input, showError(meta, validateOnMount), rest, {
    id: id || input.name,
    isRequired: isRequired,
    isReadOnly: isReadOnly,
    isDisabled: isDisabled
  })));
};

TextField.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  isDisabled: PropTypes.bool,
  id: PropTypes.string,
  FormGroupProps: PropTypes.object
};
export default TextField;

==> pf4-component-mapper-3.21.1.tgz: package/esm/text-field/text-field.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["label", "isRequired", "helperText", "meta", "validateOnMount", "description", "hideLabel", "input", "isReadOnly", "isDisabled", "id", "FormGroupProps"];
import React from 'react';
import FormGroup from '../form-group/form-group';
import { TextInput } from "@patternfly/react-core/dist/dynamic/components/TextInput";
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import showError from '../show-error/show-error';

var TextField = function TextField(props) {
  var _useFieldApi = useFieldApi(props),
      label = _useFieldApi.label,
      isRequired = _useFieldApi.isRequired,
      helperText = _useFieldApi.helperText,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      description = _useFieldApi.description,
      hideLabel = _useFieldApi.hideLabel,
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      id = _useFieldApi.id,
      FormGroupProps = _useFieldApi.FormGroupProps,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  return /*#__PURE__*/React.createElement(FormGroup, {
    label: label,
    isRequired: isRequired,
    helperText: helperText,
    meta: meta,
    validateOnMount: validateOnMount,
    description: description,
    hideLabel: hideLabel,
    id: id || input.name,
    FormGroupProps: FormGroupProps
  }, /*#__PURE__*/React.createElement(TextInput, _extends({}, input, showError(meta, validateOnMount), rest, {
    id: id || input.name,
    isRequired: isRequired,
    isReadOnly: isReadOnly,
    isDisabled: isDisabled,
    readOnly: isReadOnly
  })));
};

TextField.propTypes = {
  label: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  description: PropTypes.node,
  hideLabel: PropTypes.bool,
  isDisabled: PropTypes.bool,
  id: PropTypes.string,
  FormGroupProps: PropTypes.object
};
export default TextField;
